<?php
/*
    "WordPress Plugin Template" Copyright (C) 2018 Michael Simpson  (email : michael.d.simpson@gmail.com)

    This file is part of WordPress Plugin Template for WordPress.

    WordPress Plugin Template is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    WordPress Plugin Template is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Contact Form to Database Extension.
    If not, see http://www.gnu.org/licenses/gpl-3.0.html
*/

function WoocommerceAliexpressDropshipping_init($file) {

    require_once('WoocommerceAliexpressDropshipping_Plugin.php');
    $aPlugin = new WoocommerceAliexpressDropshipping_Plugin();

    // Install the plugin
    // NOTE: this file gets run each time you *activate* the plugin.
    // So in WP when you "install" the plugin, all that does it dump its files in the plugin-templates directory
    // but it does not call any of its code.
    // So here, the plugin tracks whether or not it has run its install operation, and we ensure it is run only once
    // on the first activation
    if (!$aPlugin->isInstalled()) {
        $aPlugin->install();
    }
    else {
        // Perform any version-upgrade activities prior to activation (e.g. database changes)
        $aPlugin->upgrade();
    }

    // Add callbacks to hooks
    $aPlugin->addActionsAndFilters();

    if (!$file) {
        $file = __FILE__;
    }
    // Register the Plugin Activation Hook
    register_activation_hook($file, array(&$aPlugin, 'activate'));


    // Register the Plugin Deactivation Hook
    register_deactivation_hook($file, array(&$aPlugin, 'deactivate'));
}



function theShark_alibay_getProduct_FROMWP()
{

  $paged = isset($_POST['paged']) ? wc_clean($_POST['paged']) : '';

  $args = array(
    'post_type'      => 'product',
    'post_status' => array('publish', 'draft'),
    'paged' => $paged,
    'posts_per_page' => 100,
    'meta_query' => array(
      'relation' => 'OR',
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'aliexpress',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'ebay',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'amazon',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'etsy',
        'compare' => 'LIKE'
      )
      ));

  $products = new WP_Query($args);
  $finalList = array();

  if ($products->have_posts()) {
    while ($products->have_posts()) : $products->the_post();
      $theid = get_the_ID();
      $product = new WC_Product($theid);
      if (has_post_thumbnail()) {
        $thumbnail = get_post_thumbnail_id();
        $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
      }
      $finalList[] = array(
        'sku' => $product->get_sku(),
        'id' => $theid,
        // image => wp_get_attachment_image_src( get_post_thumbnail_id($products->post->ID)),
        'image' => $image,
        'title' =>  $product->get_title(),
        'productUrl' => get_post_meta($theid, 'productUrl', true),
        'lastUpdated' => get_post_meta($theid, 'lastUpdated', true),
        'status' => $product->get_status()



      );
    endwhile;
  } else {
    echo __('No products found');
  }
  wp_reset_postdata();

  wp_send_json($finalList);
}

function theShark_alibay_getProductsCount_FROM_WP()
{


  $args = array(
    'post_type'      => 'product',
    'post_status' => array('publish', 'draft'),
    'meta_query' => array(
      'relation' => 'OR',
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'aliexpress',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'ebay',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'amazon',
        'compare' => 'LIKE'
      ),
      array(
        'key' => 'productUrl', //meta key name here
        'value' => 'etsy',
        'compare' => 'LIKE'
      )
    )
  );
  $query = new WP_Query($args);
  $total = $query->found_posts;
  wp_reset_postdata();
  wp_send_json($total);
}



function theShark_alibay_get_categories_FROMWP()
{


$categoriesArray = array();
  
  $orderby = 'name';
  $order = 'asc';
  $hide_empty = false;
  $cat_args = array(
    'orderby'    => $orderby,
    'order'      => $order,
    'hide_empty' => $hide_empty,
  );

  $product_categories = get_terms('product_cat', $cat_args);

  foreach( $product_categories as $product_category ) {
    // if ($product_category->count > 0) {
      array_push($categoriesArray, array('name' => $product_category->name, 'count' => $product_category->count, 'term_id' => $product_category->term_id));
    // }
  }






  // 
  // 
  // 
  // 
  // 
  // 
  // 
  // 
  // 
  // 
  // 

  wp_send_json($categoriesArray);
}




function theShark_alibay_insertProductInWoocommerce()
{



  if (isset($_POST)) {
    $sku = isset($_POST['sku']) ? wc_clean($_POST['sku']) : '';
    $images = isset($_POST['images']) ? wc_clean($_POST['images']) : array();
    $categories = isset($_POST['categories']) ? wc_clean($_POST['categories']) : array();
    $title = isset($_POST['title']) ? wc_clean($_POST['title']) : '';
    $description = isset($_POST['description']) ? wp_kses_post($_POST['description']) : '';   
    $productType = isset($_POST['productType']) ? wc_clean($_POST['productType']) : 'simple';
    $regularPrice = isset($_POST['regularPrice']) ? wc_clean($_POST['regularPrice']) : '0';
    $salePrice = isset($_POST['salePrice']) ? wc_clean($_POST['salePrice']) : '0';
    $quantity = isset($_POST['quantity']) ? wc_clean($_POST['quantity']) : '0';
    $postStatus = isset($_POST['postStatus']) ? wc_clean($_POST['postStatus']) : 'draft';
    $variations = isset($_POST['variations']) ? wc_clean($_POST['variations']) : array();
    $attributes = isset($_POST['attributes']) ? wc_clean($_POST['attributes']) : array();
    $productUrl = isset($_POST['productUrl']) ? wc_clean($_POST['productUrl']) : '';
    $shortDescription = isset($_POST['shortDescription']) ? wc_clean($_POST['shortDescription']) : '';
    $importVariationImages = isset($_POST['importVariationImages']) ? wc_clean($_POST['importVariationImages']) : '';
    $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
    $tags = isset($_POST['tags']) ? wc_clean($_POST['tags']) : array();



    // $allowed_html = array(
    //   'a' => array(
    //     'href' => array(),
    //   ),
    //   'img' => array(),
    // );
    // $sanitizedDEscription = html_entity_decode($description);



    $currentImportedNumber = get_option('isAllowedToImport_alibay');
    if(isset($currentImportedNumber)){
      $finalCounter = (int) $currentImportedNumber + 1; 
      update_option('isAllowedToImport_alibay',   $finalCounter);
    }else{
      update_option('isAllowedToImport_alibay',   '1');
    }

    if(null != get_option('isAllowedToImport_alibay') && (int) get_option('isAllowedToImport_alibay') > 100){
      $results = array('error' => true, 'error_msg' => 'you have reached the permitted usage limit for this week, you can either wait 1 week to import again or upgrade to a premuim plan', 'data' => '');
      wp_send_json($results);
    } 



    // if ($productType == 'simple') {
      if ($productType == 'simple') {
     
        $product = new WC_Product_Simple();
        
        if (isset($title)) {
          $product->set_name($title);
        }
        if (isset($description)) {
          // $product->set_description($description);
        }
        if (isset($shortDescription)) {
          $product->set_short_description($shortDescription);
        }
  
        if (isset($sku)) {
          $product->set_sku($sku);
        }
  
        if (isset($postStatus)) {
          $product->set_status($postStatus);
        }
  
  
        if (isset($regularPrice)) {
          $product->set_regular_price($regularPrice);
          $product->set_price($regularPrice);
        }

        if (isset($salePrice)) {
          $product->set_sale_price($salePrice);
          // $product->set_price($salePrice);
        }
  
        if (isset($quantity)) {
          $product->set_stock_quantity($quantity);
          $product->set_manage_stock(true);
        }
  
        //   //categories
        if (is_array($categories) && count($categories)) {
          $product->set_category_ids($categories);
        }
  
      
        theShark_alibay_save_product_images_for_ebay_alibay($product, $images);
  
        
  
  
        try {
          $post_id = $product->save();
        } catch (Exception $e) {
          $results = array(
            'error' => true,
            'error_msg' => 'Error received when trying to insert the product' . $e->getMessage(),
            'data' => ''
          );
          wp_send_json($results);
        }
  
  
  
        if (isset($productUrl)) {
          update_post_meta($post_id, 'productUrl', $productUrl);
        }
  
  
  
        if (isset($post_id) && isset($tags) && count($tags)) {
          // wp_set_post_tags( $post_id, $tags, true );
          wp_set_object_terms($post_id, $tags, 'product_tag');
        }
  
  
  
  
        
  
        $attributeArray = array();
        if (is_array($attributes) && count($attributes)) {
          foreach ($attributes as $attributeValue) {
            $values = $attributeValue['values'];
            $attr_label = $attributeValue['name'];
            $isVariation = $attributeValue['variation'];

            //Create the attribute object
            $attribute = new WC_Product_Attribute();

            //pa_size tax id
            // $attribute->set_id(0); // -> SET to 0

            //pa_size slug
            $attribute->set_name($attr_label); // -> removed 'pa_' prefix

            //Set terms slugs
            $attribute->set_options($values);
 
            //If enabled
            $attribute->set_visible(1);

            //If we are going to use attribute in order to generate variations
            // $attribute->set_variation(1);

            if ($isVariation == 'true') {
              $attribute->set_variation(1);
            } else {
              $attribute->set_variation(0);
            }

            array_push($attributeArray, $attribute);
          }
          $product->set_attributes($attributeArray);
        } 


  
  
        if (isset($post_id) && isset($reviews) && count($reviews)) {
  
          foreach ($reviews as $review) {
            $comment_id = wp_insert_comment(array(
              'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
              'comment_author'       => sanitize_text_field($review['username']),
              'comment_author_email' => sanitize_text_field($review['email']), // <== Important
              'comment_author_url'   => '',
              'comment_content'      => $review['review'],
              'comment_type'         => '',
              'comment_parent'       => 0,
              'user_id'              => 5, // <== Important
              'comment_author_IP'    => '',
              'comment_agent'        => '',
              'comment_date'         => $review['datecreation'],
              'comment_approved'     => 1,
            ));
  
            // HERE inserting the rating (an integer from 1 to 5)
            update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
          }
        }
  
  
  
  
        // variations
        $results = array(
          'error' => false,
          'error_msg' => '',
          'data' => 'Product inserted successfully'
        );
        wp_send_json($results);
        // if (isset($post_id)) {
        //   // 
        // }
        // } else {
        //   $response['message'] = $post_id->get_error_message();
        //   wp_send_json($response);
        // }
      } else {
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*---------VARIABLE-----*/
      /*---------VARIABLE-----*/
      /*----------VARIABLE----*/
      /*----------VARIABLE----*/
      /*----------VARIABLE----*/
      /*-------VARIABLE-------*/
      /*---------VARIABLE-----*/
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*----------VARIABLE----*/

      //Create main product

      try {
        $product = new WC_Product_Variable();
        if (isset($title)) {
          $product->set_name($title);
        }
        if (isset($description)) {
          // $product->set_description($description);
        }
        if (isset($shortDescription)) {
          $product->set_short_description($shortDescription);
        }

        if (isset($sku)) {
          $product->set_sku($sku);
        }

        if (isset($postStatus)) {
          $product->set_status($postStatus);
        }


        //   //categories
        if (is_array($categories) && count($categories)) {
          $product->set_category_ids($categories);
        }
        //images

 
        theShark_alibay_save_product_images_alibay($product, $images);

        // if (is_array($images) && count($images)) {
        //   $attarray = array();
        //   for ($j = 0; $j < count($images); $j++) {
        //     array_push($attarray,  upload_image($images[$j], $post_id));
        //   }
        //   // set_post_thumbnail($post_id, $attarray[0]);
        //   $product->set_image_id($attarray[0]);
        //   if (sizeof($attarray) > 1) {
        //     array_shift($attarray); //removes first item of the array (because it's been set as the featured image already)
        //     $product->set_gallery_image_ids($attarray); //set the images id's left over after the array shift as the gallery images
        //   }
        // } 

        $attributeArray = array();
        if (is_array($attributes) && count($attributes)) {
          foreach ($attributes as $attributeValue) {
            $values = $attributeValue['values'];
            $attr_label = $attributeValue['name'];
            $isVariation = $attributeValue['variation'];

            //Create the attribute object
            $attribute = new WC_Product_Attribute();

            //pa_size tax id
            // $attribute->set_id(0); // -> SET to 0

            //pa_size slug
            $attribute->set_name($attr_label); // -> removed 'pa_' prefix

            //Set terms slugs
            $attribute->set_options($values);
 
            //If enabled
            $attribute->set_visible(1);

            //If we are going to use attribute in order to generate variations
            // $attribute->set_variation(1);

            if ($isVariation == 'true') {
              $attribute->set_variation(1);
            } else {
              $attribute->set_variation(0);
            }

            array_push($attributeArray, $attribute);
          }
          $product->set_attributes($attributeArray);
        } else {
          $results = array(
            'error' => true,
            'error_msg' => 'Missing attributes or variations, could not insert product ',
            'data' => ''
          );
          wp_send_json($results);
        }
      } catch (Exception $ex) {
        /* ERROR LIKE "SKU ALREADY EXISTS" */
        $results = array(
          'error' => true,
          'error_msg' => 'Error received when trying to insert the product' . $ex->getMessage(),
          'data' => ''
        );
        wp_send_json($results);
      }


      try {
        $post_id = $product->save();
      } catch (Exception $e) {
        $results = array(
          'error' => true,
          'error_msg' => 'Error received when trying to insert the product' . $ex->getMessage(),
          'data' => ''
        );
        wp_send_json($results);
      }
      if (isset($productUrl)) {
        update_post_meta($post_id, 'productUrl', $productUrl);
      }


      
      if (isset($post_id) && isset($tags) && count($tags)) {
        // wp_set_post_tags( $post_id, $tags, true );
        wp_set_object_terms($post_id, $tags, 'product_tag');

      }

      if (isset($post_id) && isset($reviews) && count($reviews)) {

        foreach ($reviews as $review) {
          $comment_id = wp_insert_comment(array(
            'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
            'comment_author'       => sanitize_text_field($review['username']),
            'comment_author_email' => sanitize_text_field($review['email']), // <== Important
            'comment_author_url'   => '',
            'comment_content'      => $review['review'],
            'comment_type'         => '',
            'comment_parent'       => 0,
            'user_id'              => 5, // <== Important
            'comment_author_IP'    => '',
            'comment_agent'        => '',
            'comment_date'         => $review['datecreation'],
            'comment_approved'     => 1,
          ));
    
          // HERE inserting the rating (an integer from 1 to 5)
          update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
        }
      }





      // wp_send_json($variations);

      if (is_array($variations) && count($variations)) {
        array_splice($variations, 2);

        foreach ($variations as $variation) {

          $attributesVariations = $variation['attributesVariations'];
          $variationToCreate = new WC_Product_Variation();
          // $variationToCreate->set_regular_price(10);
          $variationToCreate->set_parent_id($post_id);
          if (isset($variation['SKU']) && !empty($variation['SKU'])) {
            $variationToCreate->set_sku($variation['SKU']);
          }
          if (!empty(sanitize_text_field($variation['regularPrice']))) {
            $variationToCreate->set_regular_price($variation['regularPrice']);
          }

          if (!empty(sanitize_text_field($variation['salePrice']))) {
            $variationToCreate->set_sale_price($variation['salePrice']);
          }

          //set image id
          // if (!empty(sanitize_text_field($variation['salePrice']))) {
          //   $variationToCreate->set_image_id($variation['salePrice']);
          // }





          $stockProduct = sanitize_text_field($variation['availQuantity']);
          if (isset($stockProduct)) {
            $variationToCreate->set_manage_stock(true);
            $variationToCreate->set_stock_quantity($stockProduct);
            $variationToCreate->set_stock_status('instock');
          }
          $variationsArray = array();
          foreach ($attributesVariations as $attributesVariation) {
            $variationsArray[$attributesVariation['name']] = $attributesVariation['value'];

            $arrayImageId = array();
            if (($importVariationImages == 'true')) {
              // wp_send_json($importVariationImages);

              $imageVariations = $attributesVariation['image'];
              if(isset($imageVariations)){
                $imageId = false;
                foreach ($arrayImageId as $imageObject) {
                  if ($imageObject->imageVariations == $imageVariations) {
                    $imageId = $imageObject->id;
                    break;
                  }
                }
                if ($imageId != false) {
                  $variationToCreate->set_image_id($imageId);
                } else {
                  $imageIdVariation  =  theShark_alibay_save_single_variation_image_alibay($variationToCreate, $imageVariations);
                  array_push($arrayImageId, array('image' => $imageVariations, 'id' => $imageIdVariation));
                  if (isset($imageIdVariation)) {
                    $variationToCreate->set_image_id($imageIdVariation);
                  }
                }
              }
              
            }
          };
          // wp_send_json(array('variationsArray' =\\÷/> $variationsArray, 'ttt' => $attributesVariation['value']));

          $variationToCreate->set_attributes($variationsArray);
          try {
            $variationToCreate->save();
          } catch (Exception $e) {
            echo __('Error while saving variation');
          }
        }

        
      }
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'Product inserted successfully'
      );
      wp_send_json($results);
    }
  }
}


function theShark_alibay_getProductsDraft()
{

  $paged = isset($_POST['paged']) ? wc_clean($_POST['paged']) : '';

  $args = array(
    'post_type'      => 'product',
    'posts_per_page' => 20,
    'paged' => $paged,
    'meta_query' => array(
      array(
        'key' => 'isExpired', //meta key name here
        'value' => 'true',
        'compare' => 'LIKE',
      )
    )


  );


  $products = new WP_Query($args);
  $finalList = array();

  if ($products->have_posts()) {
    while ($products->have_posts()) : $products->the_post();
      $theid = get_the_ID();
      $product = new WC_Product($theid);
      if (has_post_thumbnail()) {
        $thumbnail = get_post_thumbnail_id();
        $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
      }
      $finalList[] = array(
        'sku' => $product->get_sku(),
        'id' => $theid,
        // image => wp_get_attachment_image_src( get_post_thumbnail_id($products->post->ID)),
        'image' => $image,
        'title' =>  $product->get_title(),
        'productUrl' => get_post_meta($theid, 'productUrl', true)

      );
    endwhile;
  } else {
    echo __('No products found');
  }
  wp_reset_postdata();

  wp_send_json($finalList);
}





function theShark_alibay_getOldProductDetails()
{
  // $productUrl = 'https://www.aliexpress.com/item/4001024639837.html';
  $post_id = isset($_POST['post_id']) ? wc_clean($_POST['post_id']) : '';


  $product = wc_get_product($post_id);
  $oldVariations = $product->get_available_variations();


  wp_send_json($oldVariations);
}


function theShark_alibay_searchProductBySku()
{
  $searchSkuValue = isset($_POST['searchSkuValue']) ? wc_clean($_POST['searchSkuValue']) : '';

  if (isset($searchSkuValue)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => 1,
      'meta_query' => array(
        array(
          "key" => "_sku",
          "value" => $searchSkuValue,
          "compare" => "LIKE"
        ),
        array(
          'key' => 'productUrl', //meta key name here
          'value' => 'aliexpress.com/item',
          'compare' => 'LIKE',
        )
      )
    );





    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);
        if (has_post_thumbnail()) {
          $thumbnail = get_post_thumbnail_id();
          $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
        }
        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          // image => wp_get_attachment_image_src( get_post_thumbnail_id($products->post->ID)),
          'image' => $image,
          'title' =>  $product->get_title(),
          'productUrl' => get_post_meta($theid, 'productUrl', true)

        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  } else {
    $results = array(
      'error' => true,
      'error_msg' => 'cannot find result for the introduced sku value, please make sure the product is imported using theshark',
      'data' => ''
    );
    wp_send_json($results);
  }
}






function theShark_alibay_removeProductFromShop()
{
  $post_id = isset($_POST['post_id']) ? wc_clean($_POST['post_id']) : '';
  if (isset($post_id)) {
    $id_remove = wp_delete_post($post_id);
    if ($id_remove != false && isset($id_remove)) {
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'removed successfully'
      );
      wp_send_json($results);
    } else {
      $results = array(
        'error' => trye,
        'error_msg' => 'error while removing the product',
        'data' => ''
      );
      wp_send_json($results);
    }
  }
}




function theShark_alibay_insertReviewsIntoProduct()
{
  $post_id = isset($_POST['post_id']) ? wc_clean($_POST['post_id']) : '';
  $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
  $insertedSuccessfully = array();
  if (isset($post_id) && isset($reviews) && count($reviews)) {

    foreach ($reviews as $review) {
      $comment_id = wp_insert_comment(array(
        'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
        'comment_author'       => sanitize_text_field($review['username']),
        'comment_author_email' => sanitize_text_field($review['email']), // <== Important
        'comment_author_url'   => '',
        'comment_content'      => sanitize_text_field($review['review']),
        'comment_type'         => '',
        'comment_parent'       => 0,
        'user_id'              => 5, // <== Important
        'comment_author_IP'    => '',
        'comment_agent'        => '',
        'comment_date'         => date('Y-m-d H:i:s'),
        'comment_approved'     => 1,
      ));

      // HERE inserting the rating (an integer from 1 to 5)
      $response = update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
      if ($response != false && isset($response)) {
        array_push($insertedSuccessfully, $comment_id);
      }
    }
    wp_send_json(array('insertedSuccessfully' => $insertedSuccessfully));
  }
}





function theShark_alibay_getAlreadyImportedProducts()
{
  $listOfSkus = isset($_POST['listOfSkus']) ? wc_clean($_POST['listOfSkus']) : array();

  if (isset($listOfSkus) && count($listOfSkus)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => 40,
      'meta_query' => array(
        array(
          "key" => "_sku",
          "value" => $listOfSkus,
          "compare" => "IN"
        ), array(
          'key' => 'productUrl', //meta key name here
          'value' => 'aliexpress.com/item',
          'compare' => 'LIKE',
        )
      )
    );
    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);

        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          'title' =>  $product->get_title(),
          'productUrl' => get_post_meta($theid, 'productUrl', true)
          
        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  }
}





function theShark_alibay_getSKuAbdUrlByCategory_alibay()
{

  $categoryId = isset($_POST['categoryId']) ? wc_clean($_POST['categoryId']) : array();

  if (isset($categoryId)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => -1,
      'post_status' => array('publish'),
      'meta_query' => array(
        array(
          'key' => 'productUrl', //meta key name here
          'value' => 'aliexpress.com/item',
          'compare' => 'LIKE',
        )
      ),
      'tax_query'             => array(
        array(
          'taxonomy'      => 'product_cat',
          'field' => 'term_id', //This is optional, as it defaults to 'term_id'
          'terms'         => $categoryId,
          'operator'      => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
        )
      )


    );
    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);
        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          'productUrl' => get_post_meta($theid, 'productUrl', true)

        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  }
}







function theShark_alibay_searchCategoryByName()
{
  $searchCategoryByNameInput = isset($_POST['searchCategoryByNameInput']) ? wc_clean($_POST['searchCategoryByNameInput']) : array();
  $product_categories  = get_terms('category', array('search' => $searchCategoryByNameInput));
  wp_send_json($product_categories);
}



function theShark_alibay_save_product_images_alibay($product, $images)
{
  if (is_array($images)) {
    array_splice($images, 1);

    $gallery = array();
    foreach ($images as $key => $image) {
      if (isset($image)) {
        $upload = wc_rest_upload_image_from_url(esc_url_raw($image));
        if (is_wp_error($upload)) {
          if (!apply_filters('woocommerce_rest_suppress_image_upload_error', false, $upload, $product->get_id(), $images)) {
            throw new WC_REST_Exception('woocommerce_product_image_upload_error', $upload->get_error_message(), 400);
          } else {
            continue;
          }
        }
        $attachment_id = wc_rest_set_uploaded_image_as_attachment($upload, $product->get_id());
      }
      if ($key == 0) {
        $product->set_image_id($attachment_id);
      } else {
        array_push($gallery, $attachment_id);
      }
    }
    if (!empty($gallery)) {
      $product->set_gallery_image_ids($gallery);
    }
  } else {
    $product->set_image_id('');
    $product->set_gallery_image_ids(array());
  }
  return $product;
}


function theShark_alibay_save_single_variation_image_alibay($product, $image)
{
    $gallery = array();
      if (isset($image)) {
        $upload = wc_rest_upload_image_from_url(esc_url_raw($image));
        if (is_wp_error($upload)) {
          if (!apply_filters('woocommerce_rest_suppress_image_upload_error', false, $upload, $product->get_id(), $image)) {
            throw new WC_REST_Exception('woocommerce_product_image_upload_error', $upload->get_error_message(), 400);
          }
        }
        $attachment_id = wc_rest_set_uploaded_image_as_attachment($upload, $product->get_id());
      }
      $product->set_image_id($attachment_id);
  return $attachment_id;
}


function theShark_alibay_searchProductByIdReviews_alibay()
{
  $searchSkuValue = isset($_POST['searchSkuValue']) ? sanitize_text_field($_POST['searchSkuValue']) : '';

  if (isset($searchSkuValue)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => 1,
      'p' => $searchSkuValue
      // 'meta_query' => array(
      //   array(
      //     "key" => "_sku",
      //     "value" => $searchSkuValue,
      //     "compare" => "LIKE"
      //   )
      // )
    );





    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);
        if (has_post_thumbnail()) {
          $thumbnail = get_post_thumbnail_id();
          $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
        }
        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          // image => wp_get_attachment_image_src( get_post_thumbnail_id($products->post->ID)),
          'image' => $image,
          'title' =>  $product->get_title(),
          'productUrl' => get_post_meta($theid, 'productUrl', true),
          'lastUpdated' => get_post_meta($theid, 'lastUpdated', true),
          'status' => $product->get_status()


        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  } else {
    $results = array(
      'error' => true,
      'error_msg' => 'cannot find result for the introduced sku value, please make sure the product is imported using theShark',
      'data' => ''
    );
    wp_send_json($results);
  }
}



function theShark_alibay_saveOptionsDB_alibay()
{
  $isShippingCostEnabled = isset($_POST['isShippingCostEnabled']) ? sanitize_text_field($_POST['isShippingCostEnabled']) : 'N';
  $isEnableAutomaticUpdateForAvailability = isset($_POST['isEnableAutomaticUpdateForAvailability']) ? sanitize_text_field($_POST['isEnableAutomaticUpdateForAvailability']) : 'N';
  $isUpdateRegularPrice = isset($_POST['isUpdateRegularPrice']) ? sanitize_text_field($_POST['isUpdateRegularPrice']) : 'N';
  $isUpdateSalePrice = isset($_POST['isUpdateSalePrice']) ? sanitize_text_field($_POST['isUpdateSalePrice']) : 'N';
  $isUpdateStock = isset($_POST['isUpdateStock']) ? sanitize_text_field($_POST['isUpdateStock']) : 'N';
  $priceFormulaIntervalls = isset($_POST['priceFormulaIntervalls']) ? wc_clean($_POST['priceFormulaIntervalls']) : array();
  $onlyPublishProductWillSync = isset($_POST['onlyPublishProductWillSync']) ? sanitize_text_field($_POST['onlyPublishProductWillSync']) : 'N';
  $enableAutomaticUpdates = isset($_POST['enableAutomaticUpdates']) ? sanitize_text_field($_POST['enableAutomaticUpdates']) : 'N';
  $applyPriceFormulaAutomaticUpdate = isset($_POST['applyPriceFormulaAutomaticUpdate']) ? sanitize_text_field($_POST['applyPriceFormulaAutomaticUpdate']) : 'N';
  $syncRegularPrice = isset($_POST['syncRegularPrice']) ? sanitize_text_field($_POST['syncRegularPrice']) : 'N';
  $syncSalePrice = isset($_POST['syncSalePrice']) ? sanitize_text_field($_POST['syncSalePrice']) : 'N';
  $syncStock = isset($_POST['syncStock']) ? sanitize_text_field($_POST['syncStock']) : 'N';
  $_savedConfiguration = isset($_POST['_savedConfiguration']) ? wc_clean($_POST['_savedConfiguration']) : null;

  if (isset(  $_savedConfiguration)) {
    update_option('_savedConfiguration_alibay',   $_savedConfiguration);
  }



  if (isset($syncRegularPrice)) {
    update_option('alibay_aliexpress_syncRegularPrice', $syncRegularPrice);
  }

  if (isset($syncSalePrice)) {
    update_option('alibay_aliexpress_syncSalePrice', $syncSalePrice);
  }

  if (isset($syncStock)) {
    update_option('alibay_aliexpress_syncStock', $syncStock);
  }

  // wp_send_json($updateVariationsOnServer);
  if (isset($priceFormulaIntervalls)) {
    update_option('alibay_aliexpress_priceFormulaIntervalls', $priceFormulaIntervalls);
  }

  if (isset($isShippingCostEnabled)) {
    update_option('alibay_aliexpress_isShippingCostEnabled', $isShippingCostEnabled);
  }

  if (isset($isEnableAutomaticUpdateForAvailability)) {
    update_option('alibay_aliexpress_isEnableAutomaticUpdateForAvailability', $isEnableAutomaticUpdateForAvailability);
  }

  if (isset($isUpdateRegularPrice)) {
    update_option('alibay_aliexpress_isUpdateRegularPrice', $isUpdateRegularPrice);
  }


  if (isset($isUpdateSalePrice)) {
    update_option('alibay_aliexpress_isUpdateSalePrice', $isUpdateSalePrice);
  }


  if (isset($isUpdateStock)) {
    update_option('alibay_aliexpress_isUpdateStock', $isUpdateStock);
  }
  if (isset($onlyPublishProductWillSync)) {
    update_option('alibay_aliexpress_onlyPublishProductWillSync', $onlyPublishProductWillSync);
  }
  if (isset($enableAutomaticUpdates)) {
    update_option('alibay_aliexpress_enableAutomaticUpdates', $enableAutomaticUpdates);
  }
  if (isset($applyPriceFormulaAutomaticUpdate)) {
    update_option('alibay_aliexpress_applyPriceFormulaAutomaticUpdate', $applyPriceFormulaAutomaticUpdate);
  }


  wp_send_json($isShippingCostEnabled);
}






function theShark_alibay_insertReviewsIntoProductRM_PREMUIM_PLUGIN_alibay()
{
  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
  $insertedSuccessfully = array();
  if (isset($post_id) && isset($reviews) && count($reviews)) {

    foreach ($reviews as $review) {
      $comment_id = wp_insert_comment(array(
        'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
        'comment_author'       => sanitize_text_field($review['username']),
        'comment_author_email' => sanitize_text_field($review['email']), // <== Important
        'comment_author_url'   => '',
        'comment_content'      => $review['review'],
        'comment_type'         => '',
        'comment_parent'       => 0,
        'user_id'              => 5, // <== Important
        'comment_author_IP'    => '',
        'comment_agent'        => '',
        'comment_date'         => $review['datecreation'],
        'comment_approved'     => 1,
      ));

      // HERE inserting the rating (an integer from 1 to 5)
      $response = update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
      if ($response != false && isset($response)) {
        array_push($insertedSuccessfully, $comment_id);
      }
    }
    wp_send_json(array('insertedSuccessfully' => $insertedSuccessfully));
  }
}

function theShark_alibay_restoreConfiguration_alibay(){
  $_savedConfiguration  = get_option('_savedConfiguration_alibay');
  wp_send_json(array('_savedConfiguration_alibay' => $_savedConfiguration));
}



function getProductsCount_FROM_WP_for_ebay_alibay()
{

  $args = array(
    'post_type'      => 'product',
    'post_status' => array('publish', 'draft'),
    'meta_query' => array(
      array(
        'key' => 'productUrl', //meta key name here
        'value' => '.ebay.',
        'compare' => 'LIKE',
      )
    ),
  );
  $query = new WP_Query($args);
  $total = $query->found_posts;
  wp_reset_postdata();
  wp_send_json($total);
}






function theShark_alibay_insertProductInWoocommerce_for_ebay_alibay()
{


  $nonce = $_POST['nonce'];

  if (isset($_POST)) {
    $sku = isset($_POST['sku']) ? sanitize_text_field($_POST['sku']) : '';
    $images = isset($_POST['images']) ? wc_clean($_POST['images']) : array();
    $categories = isset($_POST['categories']) ? wc_clean($_POST['categories']) : array();
    $title = isset($_POST['title']) ? sanitize_text_field($_POST['title']) : '';
    $description = isset($_POST['description']) ? wp_kses_post($_POST['description']) : '';   
    $productType = isset($_POST['productType']) ? sanitize_text_field($_POST['productType']) : 'simple';
    $regularPrice = isset($_POST['regularPrice']) ? sanitize_text_field($_POST['regularPrice']) : '0';
    $salePrice = isset($_POST['salePrice']) ? sanitize_text_field($_POST['salePrice']) : '0';
    $quantity = isset($_POST['quantity']) ? sanitize_text_field($_POST['quantity']) : '0';
    $postStatus = isset($_POST['postStatus']) ? sanitize_text_field($_POST['postStatus']) : 'draft';
    $variations = isset($_POST['variations']) ? wc_clean($_POST['variations']) : array();
    $attributes = isset($_POST['attributes']) ? wc_clean($_POST['attributes']) : array();
    $productUrl = isset($_POST['productUrl']) ? sanitize_text_field($_POST['productUrl']) : '';
    $shortDescription = isset($_POST['shortDescription']) ? sanitize_text_field($_POST['shortDescription']) : '';
    $importVariationImages_ebay = isset($_POST['importVariationImages_ebay']) ? sanitize_text_field($_POST['importVariationImages_ebay']) : '';
    $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
    $tags = isset($_POST['tags']) ? wc_clean($_POST['tags']) : array();



    // $allowed_html = array(
    //   'a' => array(
    //     'href' => array(),
    //   ),
    //   'img' => array(),
    // );
    // $sanitizedDEscription = html_entity_decode($description);


    $currentImportedNumber = get_option('isAllowedToImport_alibay');
    if(isset($currentImportedNumber)){
      $finalCounter = (int) $currentImportedNumber + 1; 
      update_option('isAllowedToImport_alibay',   $finalCounter);
    }else{
      update_option('isAllowedToImport_alibay',   '1');
    }

    if(null != get_option('isAllowedToImport_alibay') && (int) get_option('isAllowedToImport_alibay') > 100){
      $results = array('error' => true, 'error_msg' => 'you have reached the permitted usage limit for this week, you can either wait 1 week to import again or upgrade to a premuim plan', 'data' => '');
      wp_send_json($results);
    } 


    if ($productType == 'simple') {
     
      $product = new WC_Product_Simple();
      
      if (isset($title)) {
        $product->set_name($title);
      }
      if (isset($description)) {
        // $product->set_description($description);
      }
      if (isset($shortDescription)) {
        $product->set_short_description($shortDescription);
      }

      if (isset($sku)) {
        $product->set_sku($sku);
      }

      if (isset($postStatus)) {
        $product->set_status($postStatus);
      }


      if (isset($regularPrice)) {
        $product->set_regular_price($regularPrice);
        $product->set_price($regularPrice);
      }

      if (isset($quantity)) {
        $product->set_stock_quantity($quantity);
        $product->set_manage_stock(true);
      }

      //   //categories
      if (is_array($categories) && count($categories)) {
        $product->set_category_ids($categories);
      }

    
      theShark_alibay_save_product_images_for_ebay_alibay($product, $images);

      


      try {
        $post_id = $product->save();
      } catch (Exception $e) {
        $results = array(
          'error' => true,
          'error_msg' => 'Error received when trying to insert the product' . $e->getMessage(),
          'data' => ''
        );
        wp_send_json($results);
      }



      if (isset($productUrl)) {
        update_post_meta($post_id, 'productUrl', $productUrl);
      }



      if (isset($post_id) && isset($tags) && count($tags)) {
        // wp_set_post_tags( $post_id, $tags, true );
        wp_set_object_terms($post_id, $tags, 'product_tag');
      }




      



      if (isset($post_id) && isset($reviews) && count($reviews)) {

        foreach ($reviews as $review) {
          $comment_id = wp_insert_comment(array(
            'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
            'comment_author'       => sanitize_text_field($review['username']),
            'comment_author_email' => sanitize_text_field($review['email']), // <== Important
            'comment_author_url'   => '',
            'comment_content'      => $review['review'],
            'comment_type'         => '',
            'comment_parent'       => 0,
            'user_id'              => 5, // <== Important
            'comment_author_IP'    => '',
            'comment_agent'        => '',
            'comment_date'         => $review['datecreation'],
            'comment_approved'     => 1,
          ));

          // HERE inserting the rating (an integer from 1 to 5)
          update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
        }
      }




      // variations
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'Product inserted successfully'
      );
      wp_send_json($results);
      // if (isset($post_id)) {
      //   // 
      // }
      // } else {
      //   $response['message'] = $post_id->get_error_message();
      //   wp_send_json($response);
      // }
    } else {
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*---------VARIABLE-----*/
      /*---------VARIABLE-----*/
      /*----------VARIABLE----*/
      /*----------VARIABLE----*/
      /*----------VARIABLE----*/
      /*-------VARIABLE-------*/
      /*---------VARIABLE-----*/
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*--------VARIABLE------*/
      /*----------VARIABLE----*/

      //Create main product

      try {
        $product = new WC_Product_Variable();
        if (isset($title)) {
          $product->set_name($title);
        }
        if (isset($description)) {
          // $product->set_description($description);
        }
        if (isset($shortDescription)) {
          $product->set_short_description($shortDescription);
        }

        if (isset($sku)) {
          $product->set_sku($sku);
        }

        if (isset($postStatus)) {
          $product->set_status($postStatus);
        }


        //   //categories
        if (is_array($categories) && count($categories)) {
          $product->set_category_ids($categories);
        }
        //images


        theShark_alibay_save_product_images_for_ebay_alibay($product, $images);

       
        $attributeArray = array();
        if (is_array($attributes) && count($attributes)) {
          foreach ($attributes as $attributeValue) {
            $values = $attributeValue['values'];
            $attr_label = $attributeValue['name'];
            $isVariation = $attributeValue['variation'];

            //Create the attribute object
            $attribute = new WC_Product_Attribute();

            //pa_size tax id
            // $attribute->set_id(0); // -> SET to 0

            //pa_size slug
            $attribute->set_name($attr_label); // -> removed 'pa_' prefix

            //Set terms slugs
            $attribute->set_options($values);

            //If enabled
            $attribute->set_visible(1);

            //If we are going to use attribute in order to generate variations
            // $attribute->set_variation(1);

            if ($isVariation == 'true') {
              $attribute->set_variation(1);
            } else {
              $attribute->set_variation(0);
            }

            array_push($attributeArray, $attribute);
          }
          $product->set_attributes($attributeArray);
        } else {
          $results = array(
            'error' => true,
            'error_msg' => 'Missing attributes or variations, could not insert product ',
            'data' => ''
          );
          wp_send_json($results);
        }
      } catch (Exception $ex) {
        /* ERROR LIKE "SKU ALREADY EXISTS" */
        $results = array(
          'error' => true,
          'error_msg' => 'Error received when trying to insert the product' . $ex->getMessage(),
          'data' => ''
        );
        wp_send_json($results);
      }


      try {
        $post_id = $product->save();
      } catch (Exception $e) {
        $results = array(
          'error' => true,
          'error_msg' => 'Error received when trying to insert the product' . $ex->getMessage(),
          'data' => ''
        );
        wp_send_json($results);
      }
      if (isset($productUrl)) {
        update_post_meta($post_id, 'productUrl', $productUrl);
      }



      if (isset($post_id) && isset($tags) && count($tags)) {
        // wp_set_post_tags( $post_id, $tags, true );
        wp_set_object_terms($post_id, $tags, 'product_tag');
      }

      if (isset($post_id) && isset($reviews) && count($reviews)) {

        foreach ($reviews as $review) {
          $comment_id = wp_insert_comment(array(
            'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
            'comment_author'       => sanitize_text_field($review['username']),
            'comment_author_email' => sanitize_text_field($review['email']), // <== Important
            'comment_author_url'   => '',
            'comment_content'      => $review['review'],
            'comment_type'         => '',
            'comment_parent'       => 0,
            'user_id'              => 5, // <== Important
            'comment_author_IP'    => '',
            'comment_agent'        => '',
            'comment_date'         => $review['datecreation'],
            'comment_approved'     => 1,
          ));

          // HERE inserting the rating (an integer from 1 to 5)
          update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
        }
      }





      // wp_send_json($variations);

      if (is_array($variations) && count($variations)) {
        array_splice($variations, 2);

        foreach ($variations as $variation) {

          $attributesVariations = $variation['attributesVariations'];
          $variationToCreate = new WC_Product_Variation();
          // $variationToCreate->set_regular_price(10);
          $variationToCreate->set_parent_id($post_id);
          if (isset($variation['SKU']) && !empty($variation['SKU']) && $variation['SKU'] != 'undefined') {
            $variationToCreate->set_sku($variation['SKU']);
          }

          if (!empty(sanitize_text_field($variation['regularPrice']))) {
            $variationToCreate->set_regular_price($variation['regularPrice']);
          }

          if (!empty(sanitize_text_field($variation['salePrice']))) {
            $variationToCreate->set_sale_price($variation['salePrice']);
          }

          //set image id
          // if (!empty(sanitize_text_field($variation['salePrice']))) {
          //   $variationToCreate->set_image_id($variation['salePrice']);
          // }





          $stockProduct = sanitize_text_field($variation['availQuantity']);
          if (isset($stockProduct)) {
            $variationToCreate->set_manage_stock(true);
            $variationToCreate->set_stock_quantity($stockProduct);
            $variationToCreate->set_stock_status('instock');
          }
          $variationsArray = array();
          foreach ($attributesVariations as $attributesVariation) {
            $variationsArray[$attributesVariation['name']] = $attributesVariation['value'];

            $arrayImageId = array();
            if (($importVariationImages_ebay == 'true')) {
              // wp_send_json($importVariationImages);

              $imageVariations = $attributesVariation['image'];
              if (isset($imageVariations)) {
                $imageId = false;
                foreach ($arrayImageId as $imageObject) {
                  if ($imageObject->imageVariations == $imageVariations) {
                    $imageId = $imageObject->id;
                    break;
                  }
                }
                if ($imageId != false) {
                  $variationToCreate->set_image_id($imageId);
                } else {
                  $imageIdVariation  =  theShark_alibay_save_single_variation_image_alibay($variationToCreate, $imageVariations);
                  array_push($arrayImageId, array('image' => $imageVariations, 'id' => $imageIdVariation));
                  if (isset($imageIdVariation)) {
                    $variationToCreate->set_image_id($imageIdVariation);
                  }
                }
              }
            }
          };
          // wp_send_json(array('variationsArray' =\\÷/> $variationsArray, 'ttt' => $attributesVariation['value']));

          $variationToCreate->set_attributes($variationsArray);
          try {
            $variationToCreate->save();
          } catch (Exception $e) {
            echo __('Error while saving variations');
          }
        }
      }
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'Product inserted successfully'
      );
      wp_send_json($results);
    }
  }
}












function theShark_alibay_setProductToDraft_for_ebay_alibay()
{

  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  if (isset($post_id)) {
    $result = update_post_meta($post_id, 'isExpired', 'true');
    $post = array('ID' => $post_id, 'post_status' => 'draft');
    wp_update_post($post);
  }

  wp_send_json(array('result' => $result));
}













function theShark_alibay_updateProductSimple_for_ebay_alibay()
{

  $newProduct = isset($_POST['newProduct']) ? wc_clean($_POST['newProduct']) : array();
  if (isset($newProduct) && count($newProduct)) {
    foreach ($newProduct as $product) {

      if (isset($product['id'])) {

        // if (isset($product['salePrice'])) {
        //   // $isUpdateRegularPriceOk = update_post_meta($product['variation_id'], '_sale_price', $product['salePrice']);
        // }


        if (isset($product['regularPrice'])) {
          update_post_meta($product['id'], '_regular_price', $product['regularPrice']);
          update_post_meta($product['id'], '_price',  $product['regularPrice']);
          // wc_delete_product_transients( $product['variation_id'] );

        }


        if (isset($product['availQuantity']) &&  $product['availQuantity'] > -1) {
          // $isUpdateStockPriceOk = update_post_meta($product['variation_id'], '_stock', $product['availQuantity']);

          update_post_meta($product['id'], '_stock', $product['availQuantity']);
        }



        // if (isset($product['availQuantity']) &&  $product['availQuantity'] == 0) {
        //   array_push($outOfStock, $product['variation_id']);
        // } else {
        //   array_push($arrayOfSuccess, $product['variation_id']);
        // }
        $results = array(
          'error' => false,
          'error_msg' => '',

          'data' => array('success' => true, 'sku' => $product['productSku'])
        );
        wp_send_json($results);
      } else {
        $results = array(
          'error' => false,
          'error_msg' => '',
          'data' => array('success' => true, 'sku' => $product['productSku']),
        );
        wp_send_json($results);
      }
    }
  }
}

function theShark_alibay_updateProductVariations_for_ebay_alibay()
{
  $arrayOfError = array();
  $arrayOfSuccess = array();
  $outOfStock = array();

  $updateVariationsOnServer = isset($_POST['updateVariationsOnServer']) ? wc_clean($_POST['updateVariationsOnServer']) : array();
  $totalOldVariations = isset($_POST['totalOldVariations']) ? wc_clean($_POST['totalOldVariations']) : 1;
  // wp_send_json($updateVariationsOnServer);
  if (isset($updateVariationsOnServer) && count($updateVariationsOnServer)) {
    foreach ($updateVariationsOnServer as $product) {

      if (isset($product['variation_id'])) {
        $isUpdateRegularPriceOk = false;
        $isUpdateSalePriceOk = false;
        $isUpdateStockPriceOk = false;

        if (isset($product['salePrice'])) {
          $isUpdateRegularPriceOk = update_post_meta($product['variation_id'], '_sale_price', $product['salePrice']);
        }
        if (isset($product['regularPrice'])) {
          $isUpdateSalePriceOk = update_post_meta($product['variation_id'], '_regular_price', $product['regularPrice']);
          update_post_meta($product['variation_id'], '_price',  $product['regularPrice']);
          wc_delete_product_transients($product['variation_id']);
        }
        if (isset($product['availQuantity']) &&  $product['availQuantity'] > -1) {
          $isUpdateStockPriceOk = update_post_meta($product['variation_id'], '_stock', $product['availQuantity']);
        }

        if (isset($product['availQuantity']) &&  $product['availQuantity'] == 0) {
          array_push($outOfStock, $product['variation_id']);
        } else {
          array_push($arrayOfSuccess, $product['variation_id']);
        }
      }
    }
  }
  $results = array(
    'error' => false,
    'error_msg' => '',
    'data' => array('totalOldVariations' => $totalOldVariations, 'error' => $arrayOfError, 'success' => $arrayOfSuccess, 'outOfStock' => $outOfStock)
  );
  wp_send_json($results);
}
function theShark_alibay_getOldProductDetails_for_ebay_alibay()
{
  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  $product = wc_get_product($post_id);

  if ($product->get_type() == 'simple') {
    $regularPrice = $product->get_regular_price();
    $salePrice = $product->get_sale_price();
    $quantity = $product->get_stock_quantity();
    wp_send_json(array('type' => 'simple', 'quantity' => $quantity, 'regularPrice' => $regularPrice, 'salePrice' => $salePrice));
  }

  if ($product->get_type() == 'variable') {
    $oldVariations = $product->get_available_variations();
    wp_send_json($oldVariations);
  }

}


function theShark_alibay_searchProductBySku_for_ebay_alibay()
{
  $searchSkuValue = isset($_POST['searchSkuValue']) ? sanitize_text_field($_POST['searchSkuValue']) : '';

  if (isset($searchSkuValue)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => 1,
      'meta_query' => array(
        array(
          "key" => "_sku",
          "value" => $searchSkuValue,
          "compare" => "LIKE"
        ),
        array(
          'key' => 'productUrl', //meta key name here
          'value' => 'ebay.',
          'compare' => 'LIKE',
        )
      )
    );





    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);
        if (has_post_thumbnail()) {
          $thumbnail = get_post_thumbnail_id();
          $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
        }
        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          // image => wp_get_attachment_image_src( get_post_thumbnail_id($products->post->ID)),
          'image' => $image,
          'title' =>  $product->get_title(),
          'productUrl' => get_post_meta($theid, 'productUrl', true)

        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  } else {
    $results = array(
      'error' => true,
      'error_msg' => 'cannot find result for the introduced sku value, please make sure the product is imported using theShark',
      'data' => ''
    );
    wp_send_json($results);
  }
}






function theShark_alibay_removeProductFromShop_for_ebay_alibay()
{
  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  if (isset($post_id)) {
    $id_remove = wp_delete_post($post_id);
    if ($id_remove != false && isset($id_remove)) {
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'removed successfully'
      );
      wp_send_json($results);
    } else {
      $results = array(
        'error' => trye,
        'error_msg' => 'error while removing the product',
        'data' => ''
      );
      wp_send_json($results);
    }
  }
}

function theShark_alibay_insertReviewsIntoProduct_for_ebay_alibay()
{
  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
  $insertedSuccessfully = array();
  if (isset($post_id) && isset($reviews) && count($reviews)) {

    foreach ($reviews as $review) {
      $comment_id = wp_insert_comment(array(
        'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
        'comment_author'       => sanitize_text_field($review['username']),
        'comment_author_email' => sanitize_text_field($review['email']), // <== Important
        'comment_author_url'   => '',
        'comment_content'      => sanitize_text_field($review['review']),
        'comment_type'         => '',
        'comment_parent'       => 0,
        'user_id'              => 5, // <== Important
        'comment_author_IP'    => '',
        'comment_agent'        => '',
        'comment_date'         => date('Y-m-d H:i:s'),
        'comment_approved'     => 1,
      ));

      // HERE inserting the rating (an integer from 1 to 5)
      $response = update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
      if ($response != false && isset($response)) {
        array_push($insertedSuccessfully, $comment_id);
      }
    }
    wp_send_json(array('insertedSuccessfully' => $insertedSuccessfully));
  }
}

function theShark_alibay_getAlreadyImportedProducts_for_ebay_alibay()
{
  $listOfSkus = isset($_POST['listOfSkus']) ? wc_clean($_POST['listOfSkus']) : array();

  if (isset($listOfSkus) && count($listOfSkus)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => 40,
      'meta_query' => array(
        array(
          "key" => "_sku",
          "value" => $listOfSkus,
          "compare" => "IN"
        ), array(
          'key' => 'productUrl', //meta key name here
          'value' => 'ebay.',
          'compare' => 'LIKE',
        )
      )
    );
    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);

        $finalList[] = array(
          'sku' => $product->get_sku(),
          'id' => $theid,
          'title' =>  $product->get_title(),
          'productUrl' => get_post_meta($theid, 'productUrl', true)

        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  }
}


function theShark_alibay_getSKuAbdUrlByCategory_for_ebay_alibay()
{

  $categoryId = isset($_POST['categoryId']) ? wc_clean($_POST['categoryId']) : array();

  if (isset($categoryId)) {
    $args = array(
      'post_type'      => 'product',
      'posts_per_page' => -1,
      'post_status' => array('publish'),
      'meta_query' => array(
        array(
          'key' => 'productUrl', //meta key name here
          'value' => 'ebay.',
          'compare' => 'LIKE',
        )
      ),
      'tax_query'             => array(
        array(
          'taxonomy'      => 'product_cat',
          'field' => 'term_id', //This is optional, as it defaults to 'term_id'
          'terms'         => $categoryId,
          'operator'      => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
        )
      )


    );
    $products = new WP_Query($args);
    $finalList = array();

    if ($products->have_posts()) {
      while ($products->have_posts()) : $products->the_post();
        $theid = get_the_ID();
        $product = new WC_Product($theid);
        $finalList[] = array(
          sku => $product->get_sku(),
          id => $theid,
          productUrl => get_post_meta($theid, 'productUrl', true)

        );
      endwhile;
    } else {
      echo __('No products found');
    }
    wp_reset_postdata();

    wp_send_json($finalList);
  }
}

function theShark_alibay_save_product_images_for_ebay_alibay($product, $images)
{
  if (is_array($images)) {
    array_splice($images, 1);

    $gallery = array();
    foreach ($images as $key => $image) {
      if (isset($image)) {
        $upload = wc_rest_upload_image_from_url(esc_url_raw($image));
        if (is_wp_error($upload)) {
          if (!apply_filters('woocommerce_rest_suppress_image_upload_error', false, $upload, $product->get_id(), $images)) {
            throw new WC_REST_Exception('woocommerce_product_image_upload_error', $upload->get_error_message(), 400);
          } else {
            continue;
          }
        }
        $attachment_id = wc_rest_set_uploaded_image_as_attachment($upload, $product->get_id());
      }
      if ($key == 0) {
        $product->set_image_id($attachment_id);
      } else {
        array_push($gallery, $attachment_id);
      }
    }
    if (!empty($gallery)) {
      $product->set_gallery_image_ids($gallery);
    }
  } else {
    $product->set_image_id('');
    $product->set_gallery_image_ids(array());
  }
  return $product;
}


function theShark_alibay_insertReviewsIntoProductRM_for_ebay()
{
  $post_id = isset($_POST['post_id']) ? sanitize_text_field($_POST['post_id']) : '';
  $reviews = isset($_POST['reviews']) ? wc_clean($_POST['reviews']) : array();
  $insertedSuccessfully = array();
  if (isset($post_id) && isset($reviews) && count($reviews)) {

    foreach ($reviews as $review) {
      $comment_id = wp_insert_comment(array(
        'comment_post_ID'      => sanitize_text_field($post_id), // <=== The product ID where the review will show up
        'comment_author'       => sanitize_text_field($review['username']),
        'comment_author_email' => sanitize_text_field($review['email']), // <== Important
        'comment_author_url'   => '',
        'comment_content'      => $review['review'],
        'comment_type'         => '',
        'comment_parent'       => 0,
        'user_id'              => 5, // <== Important
        'comment_author_IP'    => '',
        'comment_agent'        => '',
        'comment_date'         => $review['datecreation'],
        'comment_approved'     => 1,
      ));

      // HERE inserting the rating (an integer from 1 to 5)
      $response = update_comment_meta($comment_id, 'rating', sanitize_text_field($review['rating']));
      if ($response != false && isset($response)) {
        array_push($insertedSuccessfully, $comment_id);
      }
    }
    wp_send_json(array('insertedSuccessfully' => $insertedSuccessfully));
  }
}


// function theShark_alibay_getVariationsFromEbay_alibay()
// {
//   $file = plugin_dir_path(__FILE__) . '/test.txt';
//   $open = fopen($file, "w");
//   fwrite($open, '---RRR3');

//   // $productUrl = get_post_meta($theid, 'productUrl', true);
//   $productUrl = isset($_POST['productUrl']) ? wc_clean($_POST['productUrl']) : '';

//   $curl = curl_init();
//   curl_setopt($curl, CURLOPT_URL, $productUrl);
//   curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
//   curl_setopt($curl, CURLOPT_FOLLOWLOCATION, TRUE);
//   curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
//   $output = curl_exec($curl);
//   curl_close($curl);

//   $variations = null;
//   $attributes = null;
//   if (strpos($output, 'itemVariationsMap') == true) {
//     $regSku = "/\"itemVariationsMap\":.*?}}/im";

//     if (preg_match($regSku, $output, $matches)) {
//       if (isset($matches) && isset($matches[0])) {
//         $skuList = json_decode('{' . $matches[0] . '}', true);
//         if (isset($skuList)) {
//           foreach ($skuList as $sku) {
//             // wp_send_json(array('skuList' => $sku));
//             $variations = $sku;
//           }
//         }
//       }
//     }
//     $regSku2 = "/\"menuItemMap\":.*?}}/im";
//     if (preg_match($regSku2, $output, $matches)) {
//       if (isset($matches) && isset($matches[0])) {
//         $skuList = json_decode('{' . $matches[0] . '}', true);
//         if (isset($skuList)) {
//           foreach ($skuList as $sku) {
//             // wp_send_json(array('skuList' => $sku))
//             $attributes = $sku;
//           }
//         }
//       }
//     }
//   }
//   if (isset($variations) && isset($attributes)) {
//     wp_send_json(array('$variations' => $variations, 'attributes' => $attributes));
//   }
// }



function theShark_alibay_stopAutomaticUpdates_alibay()
{
  update_option('stop_automatic_update_for_ebay', 'stop');
  wp_send_json(array('stop_automatic' => true));
}

add_action('wp_ajax_alibay-restoreConfiguration_for_ebay', 'restoreConfiguration_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-restoreConfiguration_for_ebay', 'restoreConfiguration_for_alibay');
add_action('wp_ajax_alibay-wooshark-insert-product_for_ebay', 'theShark_alibay_insertProductInWoocommerce_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-wooshark-insert-product_for_ebay', 'theShark_alibay_insertProductInWoocommerce_for_ebay_alibay');
add_action('wp_ajax_alibay-get-sku-and-url-by-Category_for_ebay', 'theShark_alibay_getSKuAbdUrlByCategory_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-get-sku-and-url-by-Category_for_ebay', 'theShark_alibay_getSKuAbdUrlByCategory_for_ebay_alibay');
add_action('wp_ajax_alibay-get-already-imported-products_for_ebay', 'theShark_alibay_getAlreadyImportedProducts_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-get-already-imported-products_for_ebay', 'theShark_alibay_getAlreadyImportedProducts_for_ebay_alibay');
add_action('wp_ajax_alibay-insert-reviews-to-product_for_ebay', 'theShark_alibay_insertReviewsIntoProduct_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-insert-reviews-to-product_for_ebay', 'theShark_alibay_insertReviewsIntoProduct_for_ebay_alibay');
add_action('wp_ajax_alibay-remove-product-from-wp_for_ebay', 'theShark_alibay_removeProductFromShop_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-remove-product-from-wp_for_ebay', 'theShark_alibay_removeProductFromShop_for_ebay_alibay');
add_action('wp_ajax_alibay-search-product-by-sku_for_ebay', 'theShark_alibay_searchProductBySku_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-search-product-by-sku_for_ebay', 'theShark_alibay_searchProductBySku_for_ebay_alibay');
add_action('wp_ajax_alibay-update-product-variations_for_ebay', 'theShark_alibay_updateProductVariations_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-update-product-variations_for_ebay', 'theShark_alibay_updateProductVariations_for_ebay_alibay');
add_action('wp_ajax_alibay-update-product-simple_for_ebay', 'theShark_alibay_updateProductSimple_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-update-product-simple_for_ebay', 'theShark_alibay_updateProductSimple_for_ebay_alibay');
add_action('wp_ajax_alibay-set-to-draft_for_ebay-alibay', 'theShark_alibay_setProductToDraft_for_ebay_alibay_alibay');
add_action('wp_ajax_nopriv_alibay-set-to-draft_for_ebay-alibay', 'theShark_alibay_setProductToDraft_for_ebay_alibay_alibay');
add_action('wp_ajax_alibay-get-old-product-details_for_ebay', 'theShark_alibay_getOldProductDetails_for_ebay_alibay');
add_action('wp_ajax_nopriv_alibay-get-old-product-details_for_ebay', 'theShark_alibay_getOldProductDetails_for_ebay_alibay');
add_action('wp_ajax_alibay-insert-reviews-to-productRM_for_ebay', 'theShark_alibay_insertReviewsIntoProductRM_for_ebay');
add_action('wp_ajax_nopriv_alibay-insert-reviews-to-producRMt_for_ebay', 'theShark_alibay_insertReviewsIntoProductRM_for_ebay');
// add_action('wp_ajax_alibay-get_variations_from_ebay', 'theShark_alibay_getVariationsFromEbay_alibay');
// add_action('wp_ajax_nopriv_alibay-get_variations_from_ebay', 'theShark_alibay_getVariationsFromEbay_alibay');
add_action('wp_ajax_alibay-stop_automatic_update_for_ebay', 'theShark_alibay_stopAutomaticUpdates_alibay');
add_action('wp_ajax_nopriv_alibay-stop_automatic_update_for_ebay', 'theShark_alibay_stopAutomaticUpdates_alibay');
add_action('wp_ajax_remove-product-from-wp-for-ebay', 'theShark_alibay_removeProductFromShop_forEBAY_alibay');
add_action('wp_ajax_nopriv_alibay-remove-product-from-wp-for-ebay', 'theShark_alibay_removeProductFromShop_forEBAY_alibay');
add_action('wp_ajax_insert-reviews-to-productRM-alibay', 'theShark_alibay_insertReviewsIntoProductRM_PREMUIM_PLUGIN_alibay');
add_action('wp_ajax_nopriv_insert-reviews-to-producRMt-alibay', 'theShark_alibay_insertReviewsIntoProductRM_PREMUIM_PLUGIN_alibay');
add_action('wp_ajax_restoreConfiguration-alibay', 'theShark_alibay_restoreConfiguration_alibay');
add_action('wp_ajax_nopriv_restoreConfiguration-alibay', 'theShark_alibay_restoreConfiguration_alibay');
add_action('wp_ajax_wooshark-insert-product-alibay', 'theShark_alibay_insertProductInWoocommerce');
add_action('wp_ajax_nopriv_wooshark-insert-product-alibay', 'theShark_alibay_insertProductInWoocommerce');
add_action('wp_ajax_get_products-alibay', 'theShark_alibay_getProduct_FROMWP');
add_action('wp_ajax_nopriv_get_products-alibay', 'theShark_alibay_getProduct_FROMWP');
add_action('wp_ajax_search-category-by-name-alibay', 'theShark_alibay_searchCategoryByName');
add_action('wp_ajax_nopriv_search-category-by-name-alibay', 'theShark_alibay_searchCategoryByName');
add_action('wp_ajax_get-sku-and-url-by-Category-alibay', 'theShark_alibay_getSKuAbdUrlByCategory_alibay');
add_action('wp_ajax_nopriv_get-sku-and-url-by-Category-alibay', 'theShark_alibay_getSKuAbdUrlByCategory_alibay');
add_action('wp_ajax_get-already-imported-products-alibay', 'theShark_alibay_getAlreadyImportedProducts');
add_action('wp_ajax_nopriv_get-already-imported-products-alibay', 'theShark_alibay_getAlreadyImportedProducts');
add_action('wp_ajax_insert-reviews-to-product-alibay', 'theShark_alibay_insertReviewsIntoProduct');
add_action('wp_ajax_nopriv_insert-reviews-to-product-alibay', 'theShark_alibay_insertReviewsIntoProduct');
add_action('wp_ajax_remove-product-from-wp-alibay', 'theShark_alibay_removeProductFromShop');
add_action('wp_ajax_nopriv_remove-product-from-wp-alibay', 'theShark_alibay_removeProductFromShop');
add_action('wp_ajax_search-product-by-sku-alibay', 'theShark_alibay_searchProductBySku');
add_action('wp_ajax_nopriv_search-product-by-sku-alibay', 'theShark_alibay_searchProductBySku');
add_action('wp_ajax_get_products-draft-alibay', 'theShark_alibay_getProductsDraft');
add_action('wp_ajax_nopriv_get_products-draft-alibay', 'theShark_alibay_getProductsDraft');
// add_action('wp_ajax_get-new-product-details-alibay', 'theShark_alibay_getNewProductDetails');
// add_action('wp_ajax_nopriv_get-new-product-details-alibay', 'theShark_alibay_getNewProductDetails');
add_action('wp_ajax_get-old-product-details-alibay', 'theShark_alibay_getOldProductDetails');
add_action('wp_ajax_nopriv_get-old-product-details-alibay', 'theShark_alibay_getOldProductDetails');
add_action('wp_ajax_get-product-by-id-alibay', 'theShark_alibay_searchProductByIdReviews_alibay');
add_action('wp_ajax_nopriv_get-product-by-id-alibay', 'theShark_alibay_searchProductByIdReviews_alibay');
add_action('wp_ajax_saveOptionsDB-alibay', 'theShark_alibay_saveOptionsDB_alibay');
add_action('wp_ajax_nopriv_saveOptionsDB-alibay', 'theShark_alibay_saveOptionsDB_alibay');
add_action('wp_ajax_getProductsCount-alibay', 'theShark_alibay_getProductsCount_FROM_WP');
add_action('wp_ajax_nopriv_getProductsCount-alibay', 'theShark_alibay_getProductsCount_FROM_WP');
add_action('wp_ajax_get_categories-alibay', 'theShark_alibay_get_categories_FROMWP');
add_action('wp_ajax_nopriv_get_categories-alibay', 'theShark_alibay_get_categories_FROMWP');
add_action('wp_ajax_getProductsCount_for_ebay', 'getProductsCount_FROM_WP_for_ebay_alibay');
add_action('wp_ajax_nopriv_getProductsCount_for_ebay', 'getProductsCount_FROM_WP_for_ebay_alibay');




// function getProduct_FROMWP_alibay()
// {

//   $paged = isset($_POST['paged']) ? sanitize_text_field($_POST['paged']) : '';

  


//   $args = array(
//     'post_type'      => 'product',
//     'posts_per_page' => 100,
//     'paged' => $paged,
//     'meta_query' => array(
//       array(
//         'key' => 'productUrl', //meta key name here
//         'value' => 'aliexpress.com/item',
//         'compare' => 'LIKE',
//       )
//     )


//   );

//   $products = new WP_Query($args);
//   $finalList = array();

//   if ($products->have_posts()) {
//     while ($products->have_posts()) : $products->the_post();
//       $theid = get_the_ID();
//       $product = new WC_Product($theid);
//       if (has_post_thumbnail()) {
//         $thumbnail = get_post_thumbnail_id();
//         $image = $thumbnail ? wp_get_attachment_url($thumbnail) : '';
//       }
//       $finalList[] = array(
//         'sku' => $product->get_sku(),
//         'id' => $theid,
//         'image' => $image,
//         'title' =>  $product->get_title(),
//         'productUrl' => get_post_meta($theid, 'productUrl', true),
//         'lastUpdated' => get_post_meta($theid, 'lastUpdated', true),
//         'status' => $product->get_status()
//       );
//     endwhile;
//   } else {
//     echo __('No products found');
//   }
//   // wp_reset_postdata();

//   wp_send_json($finalList);
// }



function theShark_alibay_removeProductFromShop_forEBAY_alibay()
{
  $post_id = isset($_POST['post_id']) ? wc_clean($_POST['post_id']) : '';
  if (isset($post_id)) {
    $id_remove = wp_delete_post($post_id);
    if ($id_remove != false && isset($id_remove)) {
      $results = array(
        'error' => false,
        'error_msg' => '',
        'data' => 'removed successfully'
      );
      wp_send_json($results);
    } else {
      $results = array(
        'error' => trye,
        'error_msg' => 'error while removing the product',
        'data' => ''
      );
      wp_send_json($results);
    }
  }
}